=====================
NEWS about uci-config
=====================

Overview of changes to uci-config in reverse chronological order.

dev
===


0.0.2
=====

 * revert to python2 to match current needs.

 * fix bugs in exceptions messages.

 * support a default value for RegistryOption.

 * fix comment handling for config values.

 * support Store sharing inside the same process.

 * fix comment handling for sections.

0.0.1
=====

First release.
